package com.project.zcustom.service.service.smart;

import com.alibaba.fastjson2.JSONArray;

import java.util.List;
import java.util.Map;

public interface IPlatBuildingService{
    List<Map<String, Object>> getPowerAndWaterMonth();

    List<Map<String, Object>> getAirCondition();

    List<Map<String, Object>> getTarget();

    List<Map<String, Object>> useElectricity();

    Map<String, Object> greenElectricity();

    List<Map<String, Object>> carbon();

    Map<String, Object> energyYear();

    Map<String, Object> powerYear();

    Map<String, Object> waterYear();

    Map<String, Object> frequency();

    Map<String, Object> patrol();

    List<Map<String, Object>> patrolPoint();

    int updateAirNum(Long num);

    Long getAirNum();

    Map<String, Object> getThisWeekElectricity();

    JSONArray getThisAmmeterDetail(String type);

    List<Map<String, Object>> getTodayElectricity();

    Map<String, Object> getMonthElectricity();

    Map<String, Object> getRoomLoad();

    Map<String, Object> getWarnDevice();

    JSONArray getAbnormalPoint(String type);

    JSONArray getWarnEvent();

    Map<String, Object> getWarnState();
}
